#!/bin/bash

set -e

source /scripts/utils.sh

# Prep for the artifacts deployment
cprint "Fetching self service generic job implementation jar file name"
export SELF_SERVICE_GENERIC_JOB_JAR_FILE_NAME="/artifacts/ssi-jar-deployment.json"
echo $vars | jq .SELF_SERVICE_GENERIC_JOB_JAR_FILE_NAME > $SELF_SERVICE_GENERIC_JOB_JAR_FILE_NAME
echo "Fetched the following self service generic job jar file name:"
jq . $SELF_SERVICE_GENERIC_JOB_JAR_FILE_NAME

cprint "Fetching the job names"
export DEPLOYED_JOBS_LIST="/artifacts/ssi-deployed-jobs-list.json"
echo $vars | jq .DEPLOYED_JOBS_LIST > $DEPLOYED_JOBS_LIST
echo "Fetched the following self service generic jobs that have been deployed:"
jq . $DEPLOYED_JOBS_LIST

cprint "Fetching the environment name"
export ENVIRONMENT="/artifacts/ssi-env-name.json"
echo $vars | jq .ENVIRONMENT > $ENVIRONMENT
echo "Fetched the following environment name:"
jq . $ENVIRONMENT

cprint "Fetching the regions"
export REGION="/artifacts/ssi-region.json"
echo $vars | jq .REGION > $REGION
echo "Fetched the following region name:"
jq . $REGION

# Make sure the environment variable is set
if [ -z "$TF_VAR_tools_bucket_name" ] # If not set
then
    cprint "Missing environment variable `TF_VAR_tools_bucket_name`" "red"
    exit 1
fi

print_header "Starting deployment of self service ingestion"

if [ -s $SELF_SERVICE_GENERIC_JOB_JAR_FILE_NAME ]; then
    ssi_jar=$(jq . $SELF_SERVICE_GENERIC_JOB_JAR_FILE_NAME | tr -d '"')
    echo "Uploading "/artifacts/"$ssi_jar to s3://$TF_VAR_tools_bucket_name/$ssi_jar"
    aws s3 cp "/artifacts/"$ssi_jar s3://$TF_VAR_tools_bucket_name/$ssi_jar
else
    echo "Skipping uploading of the self service ingestion jar because it's missing ...."
fi

if [ -d /artifacts/configurations ];
then
    echo "Uploading the configurations folder ... "
    aws s3 cp /artifacts/configurations s3://$TF_VAR_tools_bucket_name/configurations/ --recursive
else
    echo "Failed uploading the configurations folder ... "
fi

if [ -f /artifacts/self-service-generic-job.scala ];
then
    echo "Uploading the scala script for running the generic job ... "
    aws s3 cp /artifacts/self-service-generic-job.scala s3://$TF_VAR_tools_bucket_name/scala/self-service-generic-job.scala
else
    echo "Failed uploading the scala script for running the generic job ... "
fi

REG=$(jq -r . $REGION)
ENV=$(jq -r . $ENVIRONMENT)
JOBS_TO_EXECUTE=$(jq . $DEPLOYED_JOBS_LIST)
JOBS_TO_EXECUTE_LIST=($(echo $JOBS_TO_EXECUTE | tr "[,]\"" "\n"))

echo $REG $ENV $JOBS_TO_EXECUTE_LIST

if [ ${#JOBS_TO_EXECUTE_LIST[@]} -le 0 ]; then
    echo "JOBS_TO_EXECUTE_LIST is missing. Cannot proceed executing the AWS Glue jobs ... "
    exit 1
fi

if [ -z "$ENV" ]; then
    echo "ENVIRONMENT environment variable is missing. Cannot proceed executing the AWS Glue jobs ... "
    exit 1
fi

if [ -z "$REG" ]; then
    echo "REGION environment variable is missing. Cannot proceed executing the AWS Glue jobs ... "
    exit 1
fi

echo "Start running deployed jobs ... "

for job_name in "${JOBS_TO_EXECUTE_LIST[@]}"
do
    full_job_name="${ENV}-ssi-infra-${job_name}"

    echo "Running ${full_job_name} .... "

    job_run_id=$(aws glue start-job-run --job-name ${full_job_name} --region ${REG} | jq -r '.JobRunId')

    if [ -z "$job_run_id" ]; then
        echo "Job $full_job_name wasn't able to run. Job run id: $job_run_id"
    else
        echo "Job $full_job_name run with the following job id $job_run_id"
    fi
done

# Leave for later when working on the task for better logging
# if [ -f terraform_mcs2/config/log4j.properties ];
# then
#     echo "Uploading the log4j.propertie file ... "
#     aws s3 cp terraform_mcs2/config/log4j.properties s3://$TF_VAR_tools_bucket_name/log4j.properties
# else
#     echo "Failed uploading the log4j.propertie file ... "
# fi

print_header "Finished deployment of jobs via self service ingestion platform!"
cprint "$0 done "
